@@ -4,6 +4,10 @@ import os.path
 
 
 def install(config, options):
+    base = """!/usr/bin/env fish
+complete -c pyouter -f
+complete -c pyouter -a "(python pyouter --tasks)"
+    """
     command = string.Template("""
 complete -c $script -f
 complete -c $script -a "(python $script --tasks)"
@@ -16,7 +20,19 @@ complete -c $script -a "(python $script --tasks)"
     if not os.path.exists(plugin_dir):
         os.mkdir(plugin_dir)
 
+    content = ""
+    if os.path.exists(plugin_path):
+        with open(plugin_path) as f:
+            content = f.read()
+
+    if not content.startswith(base):
+        content = base + content
+
+    plugin = command.substitute(script=script_name)
+    if plugin not in content:
+        content += plugin
+
     with open(plugin_path, "w+") as f:
-        f.write(command.substitute(script=script_name))
+        f.write(content)
 
     print("success")
